<?php
/*
Plugin Name: Hunajapurkki
Plugin URI: http://koo.fi
Description: A widget which can be used to include honeypot trap links invisible to humans but visible to spammers harvesting e-mail addresses.
Version: 0.1
Author: Mikko Kortelainen
Author URI: http://koo.fi
License: GPL2
*/
/*  Copyright 2012  Mikko Kortelainen  (email : mikko.kortelainen@techelp.fi)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


/**
 * Adds Hunajapurkki widget.
 */
class Hunajapurkki extends WP_Widget {

  /**
   * Register widget with WordPress.
   */
  public function __construct() {
    parent::__construct(
      'hunajapurkki', // Base ID
      'Hunajapurkki', // Name
      array( 'description' => __( 'Add a honeypot link for spammers harvesting e-mail addresses. Displays nothing to humans. Get your Honeypot from ', 'text_domain' ) .
                              __( 'http://projecthoneypot.org. ', 'text_domain' )  .
                              __( 'Paste the QuickLink or your own honeypot URL to the text field.', 'text_domain' ), ) // Args
    );
  }

  /**
   * Front-end display of widget.
   *
   * @see WP_Widget::widget()
   *
   * @param array $args     Widget arguments.
   * @param array $instance Saved values from database.
   */
  public function widget( $args, $instance ) {
    extract( $args );
    $honeypot_url = apply_filters( 'widget_title', $instance['honeypot_url'] );

    echo $before_widget;
    if ( ! empty( $honeypot_url ) ) {
      /* Emit a link which should be invisible in any browser */
      echo "<div style='display: none;'><a href='$honeypot_url'><span style='display: none;'> <!-- $honeypot_url --> </span></a></div>";
    }
    echo $after_widget;
  }

  /**
   * Sanitize widget form values as they are saved.
   *
   * @see WP_Widget::update()
   *
   * @param array $new_instance Values just sent to be saved.
   * @param array $old_instance Previously saved values from database.
   *
   * @return array Updated safe values to be saved.
   */
  public function update( $new_instance, $old_instance ) {
    $instance = array();
    $instance['honeypot_url'] = strip_tags( $new_instance['honeypot_url'] );

    return $instance;
  }

  /**
   * Back-end widget form.
   *
   * @see WP_Widget::form()
   *
   * @param array $instance Previously saved values from database.
   */
  public function form( $instance ) {
    if ( isset( $instance[ 'honeypot_url' ] ) ) {
      $honeypot_url = $instance[ 'honeypot_url' ];
    }
    else {
      $honeypot_url = __( 'Enter your honeypot URL here', 'text_domain' );
    }
    ?>
    <p>
    <label for="<?php echo $this->get_field_id( 'honeypot_url' ); ?>"><?php _e( 'Honeypot URL:' ); ?></label> 
    <input class="widefat" id="<?php echo $this->get_field_id( 'honeypot_url' ); ?>" name="<?php echo $this->get_field_name( 'honeypot_url' ); ?>" type="text" value="<?php echo esc_attr( $honeypot_url ); ?>" />
    </p>
    <?php 
  }

}

// register widget
add_action( 'widgets_init', create_function( '', 'register_widget( "Hunajapurkki" );' ) );

?>
